@@ -23,7 +23,12 @@ describe 'cinder::wsgi::apache' do
         :wsgi_script_source          => platform_params[:wsgi_script_source],
         :custom_wsgi_process_options => {},
         :access_log_file             => false,
+        :access_log_pipe             => false,
+        :access_log_syslog           => false,
         :access_log_format           => false,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
       )}
     end
 
@@ -34,15 +39,11 @@ describe 'cinder::wsgi::apache' do
           :bind_host                   => '10.42.51.1',
           :port                        => 12345,
           :ssl                         => false,
-          :vhost_custom_fragment       => 'Timeout 99',
           :wsgi_process_display_name   => 'cinder-api',
           :workers                     => 37,
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/admin/path',
           },
-          :access_log_file             => '/var/log/httpd/access_log',
-          :access_log_format           => 'some format',
-          :error_log_file              => '/var/log/httpd/error_log'
         }
       end
       it { is_expected.to contain_class('cinder::params') }
@@ -58,7 +59,6 @@ describe 'cinder::wsgi::apache' do
         :ssl                       => false,
         :threads                   => 1,
         :user                      => 'cinder',
-        :vhost_custom_fragment     => 'Timeout 99',
         :workers                   => 37,
         :wsgi_daemon_process       => 'cinder-api',
         :wsgi_process_display_name => 'cinder-api',
@@ -69,9 +69,70 @@ describe 'cinder::wsgi::apache' do
         :custom_wsgi_process_options => {
           'python_path'  => '/my/python/admin/path',
         },
-        :access_log_file           => '/var/log/httpd/access_log',
-        :access_log_format         => 'some format',
-        :error_log_file            => '/var/log/httpd/error_log'
+      )}
+    end
+
+    context 'with custom access logging' do
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('cinder_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('cinder_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('cinder_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('cinder_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('cinder_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
       )}
     end
   end
